==> honey-toolkit-1.0.26.tgz: package/fn/route.js <==
const fs = require('fs');
const path = require('path');
const babylon = require('babylon');
const traverse =  require("babel-traverse").default;
const generator = require("babel-generator").default;
const t = require("babel-types");

Route = function(){

};

Route.deleteRoute = function(name){
  var fileContent = fs.readFileSync(path.resolve('./src/routes/index.js') ,'utf-8');
  fileContent = fileContent.replace(new RegExp(`\{[^}]*\/\* webpackChunkName\: '${name}' [^}]*\},`, 'm'),'');
  fs.writeFileSync(path.resolve('./src/routes/index.js') ,fileContent ,'utf-8');

  fileContent = fs.readFileSync(path.resolve('./src/routes/index.dev.js') ,'utf-8');
  fileContent = fileContent.replace(new RegExp(`\{[^}]*\/\* webpackChunkName\: '${name}' [^}]*\},`, 'm'),'');
  fs.writeFileSync(path.resolve('./src/routes/index.dev.js') ,fileContent ,'utf-8');

  console.log('done');
};

Route.createRoute = function(name, isMobile){
  var fileContent = fs.readFileSync(path.resolve('./src/routes/index.js') ,'utf-8');
  fileContent = fileContent.replace(`children: [`,`children: [
    {
      path: '/${name}',
      load: () => import(/* webpackChunkName: '${name}' */ './${name}'),${isMobile ? `
      loadMobile: () => import(/* webpackChunkName: '${name}_mb' */ './${name}/index.mb'),` : ''}
    },`);
  fs.writeFileSync(path.resolve('./src/routes/index.js') ,fileContent ,'utf-8');

  var fileContent = fs.readFileSync(path.resolve('./src/routes/index.dev.js') ,'utf-8');
  fileContent = fileContent.replace(
      `/* --- 此处为调试页面,无须上传----- */`,
      `/* --- 此处为调试页面,无须上传----- */
    {
      path: '/${name}',
      load: () => import(/* webpackChunkName: '${name}' */ './${name}'),${isMobile ? `
      loadMobile: () => import(/* webpackChunkName: '${name}_mb' */ './${name}/index.mb'),` : ''}
    },`);
  fs.writeFileSync(path.resolve('./src/routes/index.dev.js') ,fileContent ,'utf-8');

  console.log('done');
}

module.exports = Route;

==> honey-toolkit-1.0.27.tgz: package/fn/route.js <==
const fs = require('fs');
const path = require('path');
const babylon = require('babylon');
const traverse =  require("babel-traverse").default;
const generator = require("babel-generator").default;
const t = require("babel-types");

Route = function(){

};

Route.deleteRoute = function(name){
  var fileContent = fs.readFileSync(path.resolve('./src/routes/index.js') ,'utf-8');
  fileContent = fileContent.replace(new RegExp(`\{[^{}]*\/\* webpackChunkName\: '${name}' [^{}]*\},`, 'm'),'');
  fs.writeFileSync(path.resolve('./src/routes/index.js') ,fileContent ,'utf-8');

  fileContent = fs.readFileSync(path.resolve('./src/routes/index.dev.js') ,'utf-8');
  fileContent = fileContent.replace(new RegExp(`\{[^{}]*\/\* webpackChunkName\: '${name}' [^{}]*\},`, 'm'),'');
  fs.writeFileSync(path.resolve('./src/routes/index.dev.js') ,fileContent ,'utf-8');

  console.log('done');
};

Route.createRoute = function(name, isMobile){
  var fileContent = fs.readFileSync(path.resolve('./src/routes/index.js') ,'utf-8');
  fileContent = fileContent.replace(`children: [`,`children: [
    {
      path: '/${name}',
      load: () => import(/* webpackChunkName: '${name}' */ './${name}'),${isMobile ? `
      loadMobile: () => import(/* webpackChunkName: '${name}_mb' */ './${name}/index.mb'),` : ''}
    },`);
  fs.writeFileSync(path.resolve('./src/routes/index.js') ,fileContent ,'utf-8');

  var fileContent = fs.readFileSync(path.resolve('./src/routes/index.dev.js') ,'utf-8');
  fileContent = fileContent.replace(
      `/* --- 此处为调试页面,无须上传----- */`,
      `/* --- 此处为调试页面,无须上传----- */
    {
      path: '/${name}',
      load: () => import(/* webpackChunkName: '${name}' */ './${name}'),${isMobile ? `
      loadMobile: () => import(/* webpackChunkName: '${name}_mb' */ './${name}/index.mb'),` : ''}
    },`);
  fs.writeFileSync(path.resolve('./src/routes/index.dev.js') ,fileContent ,'utf-8');

  console.log('done');
}

module.exports = Route;
